/*-
 * %%----------------------------------------------------------------------------------------------
 * Archive ouverte UNIGE - AoU Admin - DownloadTokenPermissionService.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2022 - 2023 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.aou.service.security;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;

import org.springframework.stereotype.Service;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import ch.unige.solidify.exception.SolidifyRuntimeException;
import ch.unige.solidify.util.HashTool;

import ch.unige.aou.model.settings.DownloadToken;
import ch.unige.aou.repository.DownloadTokenRepository;

@Service
public class DownloadTokenPermissionService {

  private final DownloadTokenRepository downloadTokenRepository;

  public DownloadTokenPermissionService(DownloadTokenRepository downloadTokenRepository) {
    this.downloadTokenRepository = downloadTokenRepository;
  }

  public boolean isAllowed(String archiveId) {
    ServletRequestAttributes servletRequestAttributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
    if (servletRequestAttributes == null) {
      throw new SolidifyRuntimeException("Can't get servlet request attributes");
    }
    HttpServletRequest httpServletRequest = servletRequestAttributes.getRequest();

    String tokenString = null;
    if (httpServletRequest.getCookies() != null) {
      for (Cookie cookie : httpServletRequest.getCookies()) {
        String cookieName = cookie.getName();
        String cookieArchiveId = cookieName.substring(cookieName.indexOf('-') + 1);
        if (cookieArchiveId.equals(archiveId)) {
          tokenString = cookie.getValue();
        }
      }
    }
    if (tokenString == null) {
      return false;
    }
    String tokenHash = HashTool.hash(tokenString);
    DownloadToken downloadToken = this.downloadTokenRepository.findByTokenHash(tokenHash);
    if (downloadToken != null && downloadToken.getArchiveId().equals(archiveId)) {
      return true;
    }
    return false;
  }
}
