package ch.unige.aou.service.settings;
/*-
 * %%----------------------------------------------------------------------------------------------
 * Archive ouverte UNIGE - AoU Admin - StaticPageService.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2022 - 2023 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

import java.util.List;

import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.context.annotation.DependsOn;
import org.springframework.stereotype.Service;

import ch.unige.aou.business.LabeledLanguageService;
import ch.unige.aou.config.AouProperties;
import ch.unige.aou.controller.AdminController;
import ch.unige.aou.model.settings.StaticPage;
import ch.unige.aou.model.settings.StaticPageLabel;

@Service
@DependsOn({ "labeledLanguageService" })
@ConditionalOnBean(AdminController.class)
public class StaticPageService {

  List<StaticPage> staticPages;

  private final LabeledLanguageService labeledLanguageService;

  public StaticPageService(AouProperties aouProperties, LabeledLanguageService labeledLanguageService) {
    this.labeledLanguageService = labeledLanguageService;
    this.staticPages = this.buildStaticPages(aouProperties.getParameters().getStaticPages());
  }

  private List<StaticPage> buildStaticPages(List<StaticPage> staticPages) {
    for (StaticPage staticPage : staticPages) {
      for (StaticPageLabel label : staticPage.getLabels()) {
        label.setLanguage(this.labeledLanguageService.findByCode(label.getLanguageCode()));
      }
    }
    return staticPages;
  }

  public List<StaticPage> getStaticPages() {
    return this.staticPages;
  }
}
