/*-
 * %%----------------------------------------------------------------------------------------------
 * Archive ouverte UNIGE - AoU Model - EventSpecification.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2022 - 2023 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.aou.specification;

import java.util.List;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;

import ch.unige.solidify.specification.SolidifySpecification;

import ch.unige.aou.model.notification.Event;

public class EventSpecification extends SolidifySpecification<Event> {
  private static final long serialVersionUID = -9120399205173630014L;

  public EventSpecification(Event criteria) {
    super(criteria);
  }

  @Override
  protected void completePredicatesList(Root<Event> root, CriteriaQuery<?> query, CriteriaBuilder builder, List<Predicate> predicatesList) {
    if(this.criteria.getMessage() != null) {
      predicatesList.add(builder.like(root.get("message"), "%" + this.criteria.getMessage() + "%"));
    }
    if (this.criteria.getEventType() != null) {
      predicatesList.add(builder.equal(root.get("eventType").get("resId"), this.criteria.getEventType().getResId()));
    }
    if (this.criteria.getPublication() != null) {
      predicatesList.add(builder.equal(root.get("publication").get("resId"), this.criteria.getPublication().getResId()));
    }
    if (this.criteria.getTriggerBy() != null) {
      predicatesList.add(builder.equal(root.get("emitter").get("resId"), this.criteria.getTriggerBy().getResId()));
    }
  }
}
